'use client';
import { Button, type buttonVariants } from '@/components/ui';
import { type ComponentProps } from 'react';
import { type VariantProps } from 'class-variance-authority';
import { useFormStatus } from 'react-dom';
import { Loader2 } from 'lucide-react';

type SubmitButtonProps = ComponentProps<'button'> &
VariantProps<typeof buttonVariants> & {
  pendingText?: string;
  loaderClassName?: ComponentProps<'div'>['className'];
  textClassName?: ComponentProps<'p'>['className'];
};

export const SubmitButton = ({
  children,
  pendingText = 'Submitting...',
  loaderClassName = 'mr-2 h-4 w-4 animate-spin',
  textClassName = 'text-sm font-medium',
  ...props
}: SubmitButtonProps) => {
  const { pending } = useFormStatus();
  return (
    <Button
      className='cursor-pointer'
      type='submit'
      aria-disabled={pending}
      {...props}
    >
      {pending || props.disabled ? (
        <>
          <Loader2 className={loaderClassName} />
          <p className={textClassName}>{pendingText}</p>
        </>
      ) : (
          children
      )}
    </Button>
  );
};
