'use client';
import * as React from 'react';
import * as AvatarPrimitive from '@radix-ui/react-avatar';
import { User } from 'lucide-react';
import { cn } from '@/lib/utils';
import { AvatarImage } from '@/components/ui/avatar';

type BasedAvatarProps = React.ComponentProps<typeof AvatarPrimitive.Root> & {
  src?: string | null;
  fullName?: string | null;
  imageClassName?: string;
  fallbackClassName?: string;
  userIconSize?: number;
};

const BasedAvatar = ({
  src = null,
  fullName = null,
  imageClassName = '',
  fallbackClassName = '',
  userIconSize = 32,
  className,
  ...props
}: BasedAvatarProps) => {
  return (
    <AvatarPrimitive.Root
      data-slot='avatar'
      className={cn(
        'cursor-pointer relative flex size-8 shrink-0 overflow-hidden rounded-full',
        className,
      )}
      {...props}
    >
      {src ? (
        <AvatarImage src={src} className={imageClassName} />
      ) : (
        <AvatarPrimitive.Fallback
          data-slot='avatar-fallback'
          className={cn(
            'bg-muted flex size-full items-center justify-center rounded-full',
            fallbackClassName,
          )}
        >
          {fullName ? (
            fullName
              .split(' ')
              .map((n) => n[0])
              .join('')
              .toUpperCase()
          ) : (
            <User size={userIconSize} />
          )}
        </AvatarPrimitive.Fallback>
      )}
    </AvatarPrimitive.Root>
  );
};

export { BasedAvatar };
